pub enum RedisEventBusError {
Open(String),
EmptyTopic,
Publish(String),
Subscribe(String),
StreamEnded,
}Expand description
Redis event transport errors returned while creating a publisher.
Variants
Open(String)
The Redis client could not be created from the configured URL.
EmptyTopic
A configured event topic is empty.
Publish(String)
Publishing failed.
Subscribe(String)
Opening a subscription failed.
StreamEnded
An active subscription ended unexpectedly.