pub struct RedisEventBus { /* private fields */ }Expand description
Redis-backed transient event publisher and reconnecting subscriber.
Implementations
Sourceimpl RedisEventBus
impl RedisEventBus
Sourcepub fn from_url(
url: &str,
topic: impl Into<String>,
) -> Result<Self, RedisEventBusError>
pub fn from_url( url: &str, topic: impl Into<String>, ) -> Result<Self, RedisEventBusError>
Creates a bus from a Redis URL and logical topic.
Sourcepub fn from_client(client: Client, topic: impl Into<String>) -> Self
pub fn from_client(client: Client, topic: impl Into<String>) -> Self
Creates a bus from an existing Redis client.
Sourcepub fn with_reconnect_policy(self, policy: RedisEventReconnectPolicy) -> Self
pub fn with_reconnect_policy(self, policy: RedisEventReconnectPolicy) -> Self
Overrides the reconnect policy.
Sourcepub async fn publish(
&self,
payload: impl Into<String>,
) -> Result<(), RedisEventBusError>
pub async fn publish( &self, payload: impl Into<String>, ) -> Result<(), RedisEventBusError>
Publishes one opaque payload. Payload interpretation belongs to the product layer.
Sourcepub async fn subscribe(
&self,
) -> Result<RedisEventSubscription, RedisEventBusError>
pub async fn subscribe( &self, ) -> Result<RedisEventSubscription, RedisEventBusError>
Opens one Redis subscription attempt.
Sourcepub async fn run_subscription<F, Fut>(
&self,
shutdown: CancellationToken,
observer: Option<&dyn EventConnectionObserver>,
on_payload: F,
)
pub async fn run_subscription<F, Fut>( &self, shutdown: CancellationToken, observer: Option<&dyn EventConnectionObserver>, on_payload: F, )
Runs a reconnecting subscription until shutdown is cancelled.
Malformed Redis payloads are logged and skipped. The callback is responsible for decoding the product payload and deciding whether an event belongs to the current runtime.